@@ -4,8 +4,7 @@
 
 #include "utils/texthandler.h"
 
-#include "utils/customemoji.h"
-
+#include <QQuickTextDocument>
 #include <QTextBlock>
 #include <QTextCursor>
 #include <QTextDocument>
@@ -16,10 +15,6 @@ static const auto fsi = QStringLiteral("\u2068");
 static const auto pdi = QStringLiteral("\u2069");
 static const auto lineSeparator = QStringLiteral("\u2028");
 
-static const QRegularExpression hashtagExp(QStringLiteral("(?:<a\\b[^>]*>#<span>(\\S*)<\\/span><\\/a>)"));
-static const QRegularExpression extraneousParagraphExp(QStringLiteral("(\\s*(?:<(?:p|br)\\s*\\/?>)+\\s*<\\/p>)"));
-static const QRegularExpression extraneousBreakExp(QStringLiteral("(\\s*(?:<br\\s*\\/?>)+\\s*)<\\/p>"));
-
 QString TextHandler::fixBidirectionality(const QString &html, const QFont &font)
 {
     QTextDocument doc;
@@ -32,7 +27,7 @@ QString TextHandler::fixBidirectionality(const QString &html, const QFont &font)
     // them to behave
     // pt 1 of 475043 fix
     for (auto block = doc.begin(); block != doc.end(); block = block.next()) {
-        for (auto fragment = block.begin(); fragment != block.end(); fragment++) {
+        for (auto fragment = block.begin(); fragment != block.end(); ++fragment) {
             auto it = fragment.fragment();
 
             if (it.charFormat().isAnchor() && it.text().startsWith(QStringLiteral("@"))) {
@@ -76,15 +71,14 @@ QPair<QString, QList<QString>> TextHandler::removeStandaloneTags(QString content
         lastParagraphBegin = lastBreak;
     }
 
-    const qsizetype lastParagraphEnd = contentHtml.lastIndexOf(QStringLiteral("</p>"));
-    QString lastParagraph = contentHtml.mid(lastParagraphBegin, lastParagraphEnd - contentHtml.length());
-
     // Catch all the tags in the last paragraph of the post, but only if they are not surrounded by text
     {
+        const qsizetype lastParagraphEnd = contentHtml.lastIndexOf(QStringLiteral("</p>"));
+        const QString lastParagraph = contentHtml.mid(lastParagraphBegin, lastParagraphEnd - contentHtml.length());
         QList<QString> possibleTags;
         QString possibleLastParagraph = lastParagraph;
 
-        auto matchIterator = hashtagExp.globalMatch(possibleLastParagraph);
+        auto matchIterator = TextRegex::hashtagExp.globalMatch(possibleLastParagraph);
         while (matchIterator.hasNext()) {
             const QRegularExpressionMatch match = matchIterator.next();
             possibleTags.push_back(match.captured(1));
@@ -92,7 +86,7 @@ QPair<QString, QList<QString>> TextHandler::removeStandaloneTags(QString content
         }
 
         // If this paragraph is truly extraneous, then we can take its tags, otherwise skip.
-        auto extraneousIterator = extraneousParagraphExp.globalMatch(possibleLastParagraph);
+        const auto extraneousIterator = TextRegex::extraneousParagraphExp.globalMatch(possibleLastParagraph);
         if (extraneousIterator.hasNext()) {
             contentHtml.replace(lastParagraph, possibleLastParagraph);
             standaloneTags = possibleTags;
@@ -102,7 +96,7 @@ QPair<QString, QList<QString>> TextHandler::removeStandaloneTags(QString content
     // Ensure we remove any remaining <br>'s which will mess up the spacing in a post.
     // Example: "<p>Yosemite Valley reflections with rock<br />    </p>"
     {
-        auto matchIterator = extraneousBreakExp.globalMatch(contentHtml);
+        auto matchIterator = TextRegex::extraneousBreakExp.globalMatch(contentHtml);
         while (matchIterator.hasNext()) {
             const QRegularExpressionMatch match = matchIterator.next();
             contentHtml = contentHtml.replace(match.captured(1), QStringLiteral(""));
@@ -112,7 +106,7 @@ QPair<QString, QList<QString>> TextHandler::removeStandaloneTags(QString content
     // Ensure we remove any empty <p>'s which will mess up the spacing in a post.
     // Example: "<p>Boris Karloff (again) as Imhotep</p><p>  </p>"
     {
-        auto matchIterator = extraneousParagraphExp.globalMatch(contentHtml);
+        auto matchIterator = TextRegex::extraneousParagraphExp.globalMatch(contentHtml);
         while (matchIterator.hasNext()) {
             const QRegularExpressionMatch match = matchIterator.next();
             contentHtml = contentHtml.replace(match.captured(1), QStringLiteral(""));
@@ -133,4 +127,45 @@ QString TextHandler::replaceCustomEmojis(const QList<CustomEmoji> &emojis, const
     return processed;
 }
 
+bool TextHandler::isPostUrl(const QString &url)
+{
+    // Check if the URL is behind HTTPs, that's a good indicator as any.
+    if (!url.contains(QStringLiteral("https"))) {
+        return false;
+    }
+
+    // Then check if the URL is especially Mastodon-like.
+    static QRegularExpression mastodonRegex(QStringLiteral("(/@\\w*)/+(\\d*)"));
+    const auto match = mastodonRegex.match(url);
+
+    // There are 3 capture groups, first is the global. Second is the username, third is the post id.
+    if (match.hasMatch() && match.capturedTexts().length() == 3) {
+        return true;
+    }
+
+    // TODO: create regex to better whittle down these cases:
+    // Pleroma/Akkoma/Misskey
+    if (url.contains(QStringLiteral("/notes/"))) {
+        return true;
+    }
+
+    // Pixelfed
+    if (url.contains(QStringLiteral("/p/"))) {
+        return true;
+    }
+
+    return false;
+}
+
+void TextHandler::forceRefreshTextDocument(QQuickTextDocument *textDocument, QQuickItem *item)
+{
+    // HACK: Workaround bug QTBUG 93281, only applies to <6.7
+#if QT_VERSION < QT_VERSION_CHECK(6, 7, 0)
+    connect(textDocument->textDocument(), SIGNAL(imagesLoaded()), item, SLOT(updateWholeDocument()));
+#else
+    Q_UNUSED(textDocument)
+    Q_UNUSED(item)
+#endif
+}
+
 #include "moc_texthandler.cpp"
\ No newline at end of file
